#########################
Aldryn Commandline Client
#########################


**********
Installing
**********

``pip install aldryn-client``


****************
Using the client
****************

for more information see http://docs.aldryn.com/en/latest/client/index.html
